bcnstests

package
v0.8.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 24, 2026 License: GPL-3.0 Imports: 9 Imported by: 0

Documentation

Overview

Package bcnstests implements a test suite for bcns

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func TestCreateVolume

func TestCreateVolume(t *testing.T, sch bcns.Namespace, schemaSpec blobcache.SchemaSpec, setup func(t testing.TB, svcs []blobcache.Service))

TestCreateVolume runs a test suite for bcns.Client.CreateVolume. setup must fill svcs with working services, which can communicate with one another through peer Volumes.

func TestOpen

func TestOpen(t testing.TB, mk func(t testing.TB) (svc blobcache.Service, nsh blobcache.Handle), schemaSpec blobcache.SchemaSpec)

func TestSuite

func TestSuite(t *testing.T, sch bcns.Namespace, spec blobcache.SchemaSpec, setup func(t testing.TB, svcs []blobcache.Service))

TestSuite chekcs that the schema works on the

Types

type Entry

type Entry struct {
	Name   string
	Rights blobcache.ActionSet
	// Target refers to a Volume on the same node by index
	Target int
}

Entry is an namespace entry

type LocalVolume

type LocalVolume = blobcachetests.LocalVolume

type NS

type NS struct {
	Schema  bcns.Namespace
	Entries []Entry
}

NS is namespace contents for a volume

func (*NS) Fill

func (n *NS) Fill(ctx context.Context, tx *bcsdk.Tx, vols []blobcache.Handle) error

type Scene

type Scene = blobcachetests.Scene

type Volume

type Volume = blobcachetests.Volume

Jump to