Documentation
¶
Overview ¶
Package bcnstests implements a test suite for bcns
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func TestCreateVolume ¶
func TestCreateVolume(t *testing.T, sch bcns.Namespace, schemaSpec blobcache.SchemaSpec, setup func(t testing.TB, svcs []blobcache.Service))
TestCreateVolume runs a test suite for bcns.Client.CreateVolume. setup must fill svcs with working services, which can communicate with one another through peer Volumes.
Types ¶
type Entry ¶
type Entry struct {
Name string
Rights blobcache.ActionSet
// Target refers to a Volume on the same node by index
Target int
}
Entry is an namespace entry
type LocalVolume ¶
type LocalVolume = blobcachetests.LocalVolume
type Scene ¶
type Scene = blobcachetests.Scene
type Volume ¶
type Volume = blobcachetests.Volume
Click to show internal directories.
Click to hide internal directories.